'use strict';

var path = require('path');
var spawn = require('cross-spawn');
var rimraf = require('rimraf');

var _require = require('../../utils'),
    hasFile = _require.hasFile,
    resolveBin = _require.resolveBin,
    fromRoot = _require.fromRoot,
    getConcurrentlyArgs = _require.getConcurrentlyArgs;

var crossEnv = resolveBin('cross-env');
var rollup = resolveBin('rollup');
var args = process.argv.slice(2);
var here = function here(p) {
  return path.join(__dirname, p);
};

var useBuiltinConfig = !args.includes('--config') && !hasFile('rollup.config.js');
var config = useBuiltinConfig ? `--config ${here('../../config/rollup.config.js')}` : args.includes('--config') ? '' : '--config'; // --config will pick up the rollup.config.js file

var getCommand = function getCommand(env) {
  return `${crossEnv} BUILD_ROLLUP=true ${env} ${rollup} ${config}`;
};

var scripts = args.includes('--p-react') ? getPReactScripts() : getConcurrentlyArgs({
  esm: getCommand('BUILD_FORMAT=esm'),
  cjs: getCommand('BUILD_FORMAT=cjs'),
  umd: getCommand('BUILD_FORMAT=umd'),
  'umd.min': getCommand('BUILD_FORMAT=umd BUILD_MINIFY=true')
});

rimraf.sync(fromRoot('dist'));

var result = spawn.sync(resolveBin('concurrently'), scripts, {
  stdio: 'inherit'
});

function getPReactScripts() {
  return getConcurrentlyArgs({
    'react.esm': getCommand('BUILD_FORMAT=esm'),
    'react.cjs': getCommand('BUILD_FORMAT=cjs'),
    'react.umd': getCommand('BUILD_FORMAT=umd'),
    'react.umd.min': getCommand('BUILD_FORMAT=umd BUILD_MINIFY=true'),
    'preact.esm': getCommand('BUILD_PREACT=true BUILD_FORMAT=esm'),
    'preact.cjs': getCommand('BUILD_PREACT=true BUILD_FORMAT=cjs'),
    'preact.umd': getCommand('BUILD_PREACT=true BUILD_FORMAT=umd'),
    'preact.umd.min': getCommand('BUILD_PREACT=true BUILD_FORMAT=umd BUILD_MINIFY=true')
  });
}

process.exit(result.status);